==> haskell-monads-tf-0.1.0.3-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-monads-tf.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monads-tf
version: 0.1.0.3
id: monads-tf-0.1.0.3-LFzloq0E7zXDh1tEBRqziX
key: monads-tf-0.1.0.3-LFzloq0E7zXDh1tEBRqziX
license: BSD3
maintainer: Ross Paterson <ross@soi.city.ac.uk>
synopsis: Monad classes, using type families
description:
    Monad classes using type families, with instances for various
    monad transformers, inspired by the paper /Functional Programming
    with Overloading and Higher-Order Polymorphism/, by Mark P
    Jones, in /Advanced School of Functional Programming/, 1995
    (<http://web.cecs.pdx.edu/~mpj/pubs/springschool.html>).
    .
    This package is almost a compatible replacement for the @mtl-tf@ package.
category: Control
author: Andy Gill
exposed: False
indefinite: False
exposed-modules:
    Control.Monad.Cont Control.Monad.Cont.Class Control.Monad.Error
    Control.Monad.Error.Class Control.Monad.Identity Control.Monad.List
    Control.Monad.RWS Control.Monad.RWS.Class Control.Monad.RWS.Lazy
    Control.Monad.RWS.Strict Control.Monad.Reader
    Control.Monad.Reader.Class Control.Monad.State
    Control.Monad.State.Class Control.Monad.State.Lazy
    Control.Monad.State.Strict Control.Monad.Trans Control.Monad.Writer
    Control.Monad.Writer.Class Control.Monad.Writer.Lazy
    Control.Monad.Writer.Strict
abi: f6b37cbc5825d723bf21971ba6dcebac
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/monads-tf-0.1.0.3
library-dirs: /usr/lib/ghc-8.2.1/site-local/monads-tf-0.1.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/monads-tf-0.1.0.3
hs-libraries: HSmonads-tf-0.1.0.3-LFzloq0E7zXDh1tEBRqziX
depends:
    base-4.10.0.0 transformers-0.5.2.0
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             transformers-0.5.2.0=9705988bf0172d3bbbcdcaf65e1d842a
haddock-interfaces: /usr/share/doc/haskell-monads-tf/html/monads-tf.haddock
haddock-html: /usr/share/doc/haskell-monads-tf/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monads-tf-0.1.0.3-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-monads-tf.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monads-tf
version: 0.1.0.3
id: monads-tf-0.1.0.3-1scKDck1nyF3hHYXqW7mNz
key: monads-tf-0.1.0.3-1scKDck1nyF3hHYXqW7mNz
license: BSD3
maintainer: Ross Paterson <ross@soi.city.ac.uk>
synopsis: Monad classes, using type families
description:
    Monad classes using type families, with instances for various
    monad transformers, inspired by the paper /Functional Programming
    with Overloading and Higher-Order Polymorphism/, by Mark P
    Jones, in /Advanced School of Functional Programming/, 1995
    (<http://web.cecs.pdx.edu/~mpj/pubs/springschool.html>).
    .
    This package is almost a compatible replacement for the @mtl-tf@ package.
category: Control
author: Andy Gill
exposed: False
indefinite: False
exposed-modules:
    Control.Monad.Cont Control.Monad.Cont.Class Control.Monad.Error
    Control.Monad.Error.Class Control.Monad.Identity Control.Monad.List
    Control.Monad.RWS Control.Monad.RWS.Class Control.Monad.RWS.Lazy
    Control.Monad.RWS.Strict Control.Monad.Reader
    Control.Monad.Reader.Class Control.Monad.State
    Control.Monad.State.Class Control.Monad.State.Lazy
    Control.Monad.State.Strict Control.Monad.Trans Control.Monad.Writer
    Control.Monad.Writer.Class Control.Monad.Writer.Lazy
    Control.Monad.Writer.Strict
abi: 0c9b66ce3d9f82342ac301838c6515b5
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/monads-tf-0.1.0.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/monads-tf-0.1.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/monads-tf-0.1.0.3
hs-libraries: HSmonads-tf-0.1.0.3-1scKDck1nyF3hHYXqW7mNz
depends:
    base-4.10.1.0 transformers-0.5.2.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
haddock-interfaces: /usr/share/doc/haskell-monads-tf/html/monads-tf.haddock
haddock-html: /usr/share/doc/haskell-monads-tf/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
